
.. _RefMessageFunctions:

messagefunctions
=================
The :code:`messagefunctions` module provides various functions that can identify the
foreground hndle of an open application.

Windows only.

.. automodule:: dtactions.messagefunctions
   :members:
